@@ -1,16 +1,20 @@
-function [y] = geomean(x,DIM)
+function [y] = geomean(x,DIM,W)
 % GEOMEAN calculates the geomentric mean of data elements. 
 % 
-% 	y = geomean(x [,DIM])   is the same as 
+% 	y = geomean(x [,DIM [,W]])   is the same as 
 % 	y = mean(x,'G' [,DIM]) 
 %
 % DIM	dimension
 %	1 STD of columns
 %	2 STD of rows
 %	default or []: first DIMENSION, with more than 1 element
+% W	weights to compute weighted mean (default: [])
+%	if W=[], all weights are 1. 
+%	number of elements in W must match size(x,DIM) 
 %
 % features:
 % - can deal with NaN's (missing values)
+% - weighting of data 
 % - dimension argument also in Octave
 % - compatible to Matlab and Octave
 %
@@ -18,7 +22,7 @@ function [y] = geomean(x,DIM)
 %
 %    This program is free software; you can redistribute it and/or modify
 %    it under the terms of the GNU General Public License as published by
-%    the Free Software Foundation; either version 2 of the License, or
+%    the Free Software Foundation; either version 3 of the License, or
 %    (at your option) any later version.
 %
 %    This program is distributed in the hope that it will be useful,
@@ -30,15 +34,20 @@ function [y] = geomean(x,DIM)
 %    along with this program; If not, see <http://www.gnu.org/licenses/>.
 
 
-%	Version 1.23;	07 Jun 2002
-%	Copyright (C) 2000-2002 by Alois Schloegl <a.schloegl@ieee.org>
+%	$Id: geomean.m 5809 2009-05-12 16:13:45Z schloegl $ 
+%	Copyright (C) 2000-2002,2009 by Alois Schloegl <a.schloegl@ieee.org>
+%    	This is part of the NaN-toolbox. For more details see
+%    	   http://www.dpmi.tu-graz.ac.at/~schloegl/matlab/NaN/
 
 
 if nargin<2
         DIM=min(find(size(x)>1));
         if isempty(DIM), DIM=1; end;
+end
+if nargin<3
+	W = [];
 end;
 
-[y, n] = sumskipnan(log(x),DIM);
+[y, n] = sumskipnan(log(x),DIM,W);
 y = exp (y./n);
 
